/*
 Copyright (c) 2020 gematik GmbH

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
package de.gematik.ti.sgd.domain;

public class AesGcmEncryptionData {
    private final byte[] aesKey;
    private final String associatedData;

    public AesGcmEncryptionData(byte[] aesKey, String associatedData) {
        this.aesKey = aesKey;
        this.associatedData = associatedData;
    }

    public byte[] getAesKey() {
        return aesKey;
    }

    public String getAssociatedData() {
        return associatedData;
    }

    public static final class AesGcmEncryptionDataBuilder {
        private byte[] aesKey;
        private String associatedData;

        private AesGcmEncryptionDataBuilder() {
        }

        public static AesGcmEncryptionDataBuilder anAesGcmEncryptionData() {
            return new AesGcmEncryptionDataBuilder();
        }

        public AesGcmEncryptionDataBuilder withAesKey(byte[] aesKey) {
            this.aesKey = aesKey;
            return this;
        }

        public AesGcmEncryptionDataBuilder withAssociatedData(String associatedData) {
            this.associatedData = associatedData;
            return this;
        }

        public AesGcmEncryptionData build() {
            return new AesGcmEncryptionData(aesKey, associatedData);
        }
    }
}
