/*
 Copyright (c) 2020 gematik GmbH

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
package de.gematik.ti.sgd.domain.sgdCommunication;

import de.gematik.ti.sgd.domain.sgdCommunication.vectors.SgdVector;

import java.util.Arrays;
import java.util.List;

public abstract class SgdMessage {
    public static final String REQUEST_MESSAGE_INTRO = "KeyDerivation";
    public static final String RESPONSE_MESSAGE_INTRO = "OK-KeyDerivation";
    private static final int REQUEST_MESSAGE_PARTS = 2;
    private static final int RESPONSE_MESSAGE_PARTS = 3;

    private List<String> parts;
    private SgdVectorClassifier classifier;
    private String atToken;
    private String requestId;

    public SgdMessage(String atToken, String requestId, List<String> parts, SgdVectorClassifier classificationFromVector) {
        this.atToken = atToken;
        this.requestId = requestId;
        this.parts = parts;
        this.classifier = classificationFromVector;
    }

    public static SgdMessage parseSgdMessageFromString(String completeMessage) {
        String[] firstLevelMessageParts = completeMessage.split(" ", 3);
        //TODO message struktur enforcen!

        String atToken = firstLevelMessageParts[0];
        String requestId = firstLevelMessageParts[1];
        String secondLevelContent = firstLevelMessageParts[2];

        boolean isRequest;
        if (secondLevelContent.startsWith(REQUEST_MESSAGE_INTRO)) {
            isRequest = true;
        } else if (secondLevelContent.startsWith(RESPONSE_MESSAGE_INTRO)) {
            isRequest = false;
        } else {
            throw new RuntimeException("Illegal SgdMessage encountered! Expected start either with " + REQUEST_MESSAGE_INTRO + " or " + RESPONSE_MESSAGE_INTRO + ", but was '" + secondLevelContent + "'");
        }
        List<String> parts = Arrays.asList(secondLevelContent.split(" ", isRequest ? REQUEST_MESSAGE_PARTS : RESPONSE_MESSAGE_PARTS));
        if (isRequest) {
            return new KeyDerivationRequestSgdMessage(atToken, requestId, parts);
        } else {
            return new KeyDerivationResponseSgdMessage(atToken, requestId, parts);
        }
    }

    public List<String> getParts() {
        return parts;
    }

    public abstract SgdVector getSgdVector();

    public String getAtToken() {
        return atToken;
    }

    public String getRequestId() {
        return requestId;
    }

    public SgdVectorClassifier getClassifier() {
        return classifier;
    }


}
