
/*
 Copyright (c) 2020 gematik GmbH

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
package de.gematik.ti.sgd.domain.sgdCommunication;


import de.gematik.ti.sgd.SgdTestCryptoUtilities;
import de.gematik.ti.sgd.crypto.SgdCryptoUtilities;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.junit.BeforeClass;
import org.junit.Test;

import java.io.File;
import java.security.KeyPair;
import java.security.Security;

import static org.assertj.core.api.Assertions.assertThat;

//A_17902 gemSpec_SGD_epa
public class EncryptedMessageTest {
    private final String P12_1_FILENAME = "src/test/resources/keys/egk/109500969_X114428530_c.ch.aut-ecc.p12";

    {
        SgdCryptoUtilities.setInstance(new SgdTestCryptoUtilities());
    }

    @BeforeClass
    public static void setup() {
        Security.addProvider(new BouncyCastleProvider());
    }

    @Test
    public void encodeMessage_ShouldHavecorrectForm() {
        KeyPair receiverEphemeralKeyPair = SgdCryptoUtilities.getInstance().loadKeypairFromP12File(P12_1_FILENAME, "00", "00");
        String cleartext = "geheime nachricht!";

        EncryptedMessage message = new EncryptedMessage(receiverEphemeralKeyPair.getPublic(), cleartext);

        assertThat(message.getContent()).contains("brainpoolP256r1 ", " 0x");
        assertThat(new String(message.decryptMessage(receiverEphemeralKeyPair)))
                .isEqualTo(cleartext);
    }
}
