/*
 Copyright (c) 2020 gematik GmbH

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
package de.gematik.ti.sgd.server;

import de.gematik.ti.sgd.components.SchluesselGenerierungsDienst;
import de.gematik.ti.sgd.crypto.SgdCryptoUtilities;
import de.gematik.ti.sgd.crypto.SgdCryptoUtilitiesImplementation;
import de.gematik.ti.sgd.server.configuration.SgdServerConfiguration;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.context.annotation.Bean;
import org.springframework.scheduling.annotation.EnableScheduling;

import java.util.Collections;

@EntityScan("de.gematik.ti.aktor.db.*")
@SpringBootApplication(scanBasePackages = {"de.gematik.ti.sgd.server"})
@EnableScheduling
public class SgdExampleServer {
    @Autowired
    private SgdServerConfiguration sgdServerConfiguration;

    {
        SgdCryptoUtilities.setInstance(new SgdCryptoUtilitiesImplementation());
    }

    public static void main(String[] args) {
        SpringApplication.run(SgdExampleServer.class, args);
    }

    @Bean
    public SchluesselGenerierungsDienst schluesselGenerierungsDienst() {
        return new SchluesselGenerierungsDienst(sgdServerConfiguration.extractSgdInstanceProperties(),
                sgdServerConfiguration.getSignerCertificates(), Collections.emptyMap());
    }
}
