/*
 Copyright (c) 2020 gematik GmbH

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
package de.gematik.ti.sgd.server;

import de.gematik.ti.sgd.components.SchluesselGenerierungsDienst;
import de.gematik.ti.sgd.domain.json.SgdRequest;
import de.gematik.ti.sgd.domain.json.SgdResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;

@Consumes(value = {"application/json"})
@Produces(value = {"application/json"})
@RestController
class SgdServerController {
    @Autowired
    private SchluesselGenerierungsDienst schluesselGenerierungsDienst;

    @PostMapping("/sgd1")
    public SgdResponse handleRequestForSgd1(@RequestBody SgdRequest request) {
        if (schluesselGenerierungsDienst.isThisSgdOne()) {
            return schluesselGenerierungsDienst.receive(request);
        } else {
            throw new InvalidSgdInstanceException();
        }
    }

    @PostMapping("/sgd2")
    public SgdResponse handleRequestForSgd2(@RequestBody SgdRequest request) {
        if (schluesselGenerierungsDienst.isThisSgdOne()) {
            throw new InvalidSgdInstanceException();
        } else {
            return schluesselGenerierungsDienst.receive(request);
        }
    }

    @ResponseStatus(value = HttpStatus.NOT_FOUND)
    public static class InvalidSgdInstanceException extends RuntimeException {
    }
}
